@@ -71,6 +71,8 @@ static GtkStatusIcon *trayIcon;
 
 static char *gladeFile;
 
+static const char * ccfn;
+
 static GdkWindowState main_window_state;
 
 /**
@@ -328,14 +330,22 @@ unloadPlugin (void *p)
   return NULL;
 }
 
+const char *GNUNET_GTK_get_client_config_filename ()
+{
+  return ccfn;
+}
+
+
 void
-GNUNET_GTK_initialize_common_library (struct GNUNET_GC_Configuration *c,
+GNUNET_GTK_initialize_common_library (const char *ccfnarg,
+				      struct GNUNET_GC_Configuration *c,
                                       void *callback)
 {
   char *load;
   char *path;
   char *filename;
 
+  ccfn = ccfnarg;
   cfg = c;
   shutdown_function = callback;
   sclock = GNUNET_mutex_create (GNUNET_YES);
@@ -344,13 +354,13 @@ GNUNET_GTK_initialize_common_library (struct GNUNET_GC_Configuration *c,
   cron = GNUNET_cron_create (NULL);
 
   /* load the interface */
-  path = GNUNET_get_installation_path (GNUNET_IPK_DATADIR);
+  path = GNUNET_get_installation_path (GNUNET_IPK_SELF_PREFIX);
   filename =
     GNUNET_malloc (strlen (path) +
-                   strlen ("/../gnunet-gtk/gnunet-gtk.glade") + 2);
+                   strlen ("share/gnunet-gtk/gnunet-gtk.glade") + 2);
   strcpy (filename, path);
   GNUNET_free (path);
-  strcat (filename, "/../gnunet-gtk/gnunet-gtk.glade");
+  strcat (filename, "share/gnunet-gtk/gnunet-gtk.glade");
 #if MINGW
   gladeFile = GNUNET_malloc (_MAX_PATH + 1);
   plibc_conv_to_win_path (filename, gladeFile);
@@ -532,15 +542,14 @@ GNUNET_GTK_display_daemon_status (GNUNET_GTK_STATUS status,
 
       trayIcon = GNUNET_GTK_get_trayIcon ();
 
-      instDir = GNUNET_get_installation_path (GNUNET_IPK_DATADIR);
-      dataDir = g_strconcat (instDir, "/../gnunet-gtk/", NULL);
+      instDir = GNUNET_get_installation_path (GNUNET_IPK_SELF_PREFIX);
+      dataDir = g_strconcat (instDir, "share/gnunet-gtk/", NULL);
 #if MINGW
       finalPath = GNUNET_malloc (_MAX_PATH + 1);
       plibc_conv_to_win_path (dataDir, finalPath);
 #else
       finalPath = GNUNET_strdup (dataDir);
 #endif
-      GNUNET_free (instDir);
       g_free (dataDir);
       iconSource = gtk_icon_source_new ();
 
@@ -550,8 +559,9 @@ GNUNET_GTK_display_daemon_status (GNUNET_GTK_STATUS status,
       gtk_icon_source_set_filename (iconSource, iconPath);
       g_free (iconPath);
       gtk_icon_set_add_source (iconSet, iconSource);
-      iconPath = g_build_filename (instDir, "..", "gnunet-gtk",
+      iconPath = g_build_filename (instDir, "share", "gnunet-gtk",
                                    "gnunet-gtk-status-connected.png", NULL);
+      GNUNET_free (instDir);
       absPath = GNUNET_expand_file_name(NULL, iconPath);
       gtk_icon_source_set_filename (iconSource, absPath);
       GNUNET_free(absPath);
@@ -830,92 +840,6 @@ GNUNET_GTK_get_main_window_state ()
   return main_window_state;
 }
 
-/**
- * Start gnunet-setup, asking for a password if needed
- */
-gboolean
-GNUNET_GTK_run_gnunet_setup (gchar * conffile, gboolean run_wizard)
-{
-  GtkWidget *mainWindow;
-  GtkWidget *messageDialog;
-  GError *gerror = NULL;
-  char *error_message = NULL;
-
-  if (0 == ACCESS (conffile, W_OK))
-    {
-      if (run_wizard)
-        {
-          char *argv[]
-            = { "gnunet-setup", "-d", "wizard-gtk", "-c", conffile, NULL };
-          g_spawn_async (NULL, argv, NULL,
-                         G_SPAWN_SEARCH_PATH | G_SPAWN_CHILD_INHERITS_STDIN,
-                         NULL, NULL, NULL, &gerror);
-        }
-      else
-        {
-          char *argv[]
-            = { "gnunet-setup", "-d", "gconfig", "-c", conffile, NULL };
-          g_spawn_async (NULL, argv, NULL,
-                         G_SPAWN_SEARCH_PATH | G_SPAWN_CHILD_INHERITS_STDIN,
-                         NULL, NULL, NULL, &gerror);
-        }
-      if (gerror)
-        {
-          error_message = GNUNET_strdup (gerror->message);
-          g_error_free (gerror);
-        }
-    }
-  else
-#ifndef WITH_LIBGKSU2
-    {
-      error_message =
-        GNUNET_strdup (_
-                       ("You don't have rights to write to the provided configuration file."));
-    }
-#else
-    {
-      char *commandline;
-
-      if (run_wizard)
-        {
-          commandline =
-            g_strconcat ("gnunet-setup -d wizard-gtk -c ", conffile, NULL);
-          gksu_run (commandline, &gerror);
-        }
-      else
-        {
-          commandline =
-            g_strconcat ("gnunet-setup -d gconfig -c ", conffile, NULL);
-          gksu_run (commandline, &gerror);
-        }
-      GNUNET_free (commandline);
-      if (gerror)
-        {
-          error_message = GNUNET_strdup (gerror->message);
-          g_error_free (gerror);
-        }
-    }
-#endif
-  if (error_message)
-    {
-      mainWindow =
-        glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (), "mainWindow");
-      messageDialog =
-        gtk_message_dialog_new (GTK_WINDOW (mainWindow),
-                                GTK_DIALOG_MODAL |
-                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
-                                _
-                                ("Failed to run the configuration tool (gnunet-setup): %s"),
-                                error_message);
-      gtk_dialog_run (GTK_DIALOG (messageDialog));
-      gtk_widget_destroy (messageDialog);
-      GNUNET_free (error_message);
-      return FALSE;
-    }
-  return TRUE;
-}
-
 GtkWidget *
 GNUNET_GTK_extract_main_widget_from_window (GladeXML * xml,
                                             const char *windowName)
