@@ -666,14 +666,10 @@ void
 initTrayIcon ()
 {
 #if GTK_CHECK_VERSION (2,10,0)
-  char *instDir;
-  char *iconPath;
   GtkStatusIcon *trayIcon;
   GtkWidget *trayContextMenu;
   GladeXML *trayContextMenuXML;
   GtkWidget *tray_quit;
-  GtkIconSet *iconSet;
-  GtkIconSource *iconSource;
 
   trayContextMenuXML =
     glade_xml_new (GNUNET_GTK_get_glade_filename (), "trayContextMenu",
@@ -681,29 +677,7 @@ initTrayIcon ()
   trayContextMenu = glade_xml_get_widget (trayContextMenuXML,
                                           "trayContextMenu");
   trayIcon = GNUNET_GTK_get_trayIcon ();
-  instDir = GNUNET_get_installation_path (GNUNET_IPK_DATADIR);
-  iconSet = gtk_icon_set_new ();
-  iconSource = gtk_icon_source_new ();
-  iconPath =
-    g_build_filename (instDir, "..", "gnunet-gtk",
-                      "gnunet-gtk-status-connected.svg", NULL);
-  gtk_icon_source_set_filename (iconSource, iconPath);
-  g_free (iconPath);
-  gtk_icon_set_add_source (iconSet, iconSource);
-  iconPath =
-    g_build_filename (instDir, "..", "gnunet-gtk",
-                      "gnunet-gtk-status-connected.png", NULL);
-  gtk_icon_source_set_filename (iconSource, iconPath);
-  g_free (iconPath);
-  gtk_icon_source_set_size_wildcarded (iconSource, FALSE);
-  gtk_icon_set_add_source (iconSet, iconSource);
-
-  gtk_icon_factory_add (GNUNET_GTK_get_iconFactory (),
-                        "gnunet-gtk-status-connected", iconSet);
-  gtk_icon_set_unref (iconSet);
-  gtk_icon_source_free (iconSource);
-  GNUNET_free (instDir);
-  gtk_status_icon_set_from_stock (trayIcon, "gnunet-gtk-status-connected");
+  gtk_status_icon_set_from_icon_name (trayIcon, "gnunet-gtk");
   gtk_status_icon_set_tooltip (trayIcon, _("GNU's peer-to-peer network"));
   tray_quit = glade_xml_get_widget (trayContextMenuXML, "tray_quit");
   g_signal_connect_swapped (G_OBJECT (tray_quit), "activate",
@@ -731,10 +705,10 @@ initTrayIcon ()
   tray_quit = glade_xml_get_widget (trayContextMenuXML, "tray_quit");
 
   tray_icon = egg_tray_icon_new (_("GNU's peer-to-peer network"));
-  instDir = GNUNET_get_installation_path (GNUNET_IPK_DATADIR);
-  iconPath = GNUNET_malloc (strlen (instDir) + 40);
+  instDir = GNUNET_get_installation_path (GNUNET_IPK_SELF_PREFIX);
+  iconPath = GNUNET_malloc (strlen (instDir) + strlen ("share/gnunet-gtk/gnunet-gtk-status-connected.svg") + 1);
   strcpy (iconPath, instDir);
-  strcat (iconPath, "/../gnunet-gtk/gnunet-gtk-status-connected.svg");
+  strcat (iconPath, "share/gnunet-gtk/gnunet-gtk-status-connected.svg");
   GNUNET_free (instDir);
   pixbuf = gdk_pixbuf_new_from_file (iconPath, NULL);
   GNUNET_free (iconPath);
