@@ -30,8 +30,8 @@
 #include <GNUnet/gnunet_getoption_lib.h>
 #include <GNUnet/gnunet_stats_lib.h>
 #include <GNUnet/gnunet_util.h>
-#include <gtk/gtk.h>
 #include <glib/gerror.h>
+#include "daemon.h"
 
 #ifdef WITH_LIBGKSU2
 /* Not used because libgksu2 headers have broken depends in Debian
@@ -125,22 +125,21 @@ updateAppModel (void *dummy)
 }
 
 
-static void *
-doUpdateMenus (void *arg)
+void *
+daemon_doUpdateMenus (void *arg)
 {
   int ret = *(int *) arg;
   static GtkWidget *killEntry = NULL;
   static GtkWidget *launchEntry = NULL;
-  static GtkWidget *statsEntryYes = NULL;
-  static GtkWidget *statsEntryNo = NULL;
-  static GtkWidget *statsEntryError = NULL;
+  static GtkWidget *statsEntry = NULL;
   static GtkWidget *chooser = NULL;
   static int once = 1;
   static int isLocal;
   char *host;
   int canStart;
   struct GNUNET_GC_Configuration *dcfg;
-  char *fn;
+  const char *fn;
+  char * fnx;
   char *user;
 
   if (once)
@@ -151,21 +150,15 @@ doUpdateMenus (void *arg)
       launchEntry =
         glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
                               "startDaemon");
-      statsEntryYes =
+      statsEntry =
         glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                              "statusPixmapYes");
-      statsEntryNo =
-        glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                              "statusPixmapNo");
-      statsEntryError =
-        glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                              "statusPixmapError");
+                              "statusPixmap");
       chooser =
         glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                              "gnunetdconfigFileChooserButton");
+                              "configfilenameEntry");
       GNUNET_GC_get_configuration_value_string (cfg, "NETWORK", "HOST",
                                                 "localhost", &host);
-      if (strncmp (host, "localhost:", 10) == 0)
+      if (strncmp (host, "localhost", 9) == 0)
         isLocal = TRUE;
       else
         isLocal = FALSE;
@@ -174,12 +167,14 @@ doUpdateMenus (void *arg)
   if (ret == 0)
     {
       canStart = 0;
-      fn = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
+      fn = gtk_entry_get_text (GTK_ENTRY (chooser));
+      fnx = NULL;
       if (NULL == fn)
         GNUNET_GC_get_configuration_value_filename (cfg, "DAEMON",
                                                     "CONFIGFILE",
                                                     GNUNET_DEFAULT_DAEMON_CONFIG_FILE,
-                                                    &fn);
+                                                    &fnx);
+      fn = fnx;
       if (isLocal && fn)
         {
           if (GNUNET_disk_file_test (ectx, fn) == GNUNET_YES)
@@ -214,28 +209,30 @@ doUpdateMenus (void *arg)
               GNUNET_free (user);
               GNUNET_GC_free (dcfg);
             }
-          g_free (fn);
         }
-      gtk_widget_hide (statsEntryYes);
+      GNUNET_free_non_null(fnx);
+      gtk_image_set_from_stock (GTK_IMAGE (statsEntry), GTK_STOCK_YES,
+                                GTK_ICON_SIZE_SMALL_TOOLBAR);
       gtk_widget_set_sensitive (killEntry, FALSE);
       if (canStart && isLocal)
         {
           gtk_widget_set_sensitive (launchEntry, TRUE);
-          gtk_widget_show_all (statsEntryNo);
-          gtk_widget_hide (statsEntryError);
+          gtk_image_set_from_stock (GTK_IMAGE (statsEntry), GTK_STOCK_NO,
+                                    GTK_ICON_SIZE_SMALL_TOOLBAR);
         }
       else
         {
           gtk_widget_set_sensitive (launchEntry, FALSE);
-          gtk_widget_show_all (statsEntryError);
-          gtk_widget_hide (statsEntryNo);
+          gtk_image_set_from_stock (GTK_IMAGE (statsEntry),
+                                    GTK_STOCK_DIALOG_ERROR,
+                                    GTK_ICON_SIZE_SMALL_TOOLBAR);
+
         }
     }
   else
     {
-      gtk_widget_hide (statsEntryNo);
-      gtk_widget_hide (statsEntryError);
-      gtk_widget_show_all (statsEntryYes);
+      gtk_image_set_from_stock (GTK_IMAGE (statsEntry), GTK_STOCK_YES,
+                                GTK_ICON_SIZE_SMALL_TOOLBAR);
       gtk_widget_set_sensitive (killEntry, TRUE);
       gtk_widget_set_sensitive (launchEntry, FALSE);
     }
@@ -259,11 +256,20 @@ cronCheckDaemon (void *dummy)
     {
       updateAppModel (NULL);
       last = ret;
+      if (ret)
+        GNUNET_GTK_display_daemon_status (GNUNET_GTK_STATUS_DAEMONUP, 0);
+      else
+        GNUNET_GTK_display_daemon_status (GNUNET_GTK_STATUS_NODAEMON, 0);
     }
-  GNUNET_GTK_save_call (&doUpdateMenus, &ret);
+  GNUNET_GTK_save_call (&daemon_doUpdateMenus, &ret);
 }
 
 
+/* in setup.c */
+void
+on_gnunetdconfigfile_changed_daemon (GtkWidget * wid, gpointer data);
+
+
 /**
  * Launch gnunetd w/ checks
  */
@@ -271,6 +277,7 @@ void
 on_startDaemon_clicked_daemon (GtkWidget * widget, gpointer data)
 {
   GtkWidget *launchEntry;
+  GtkWidget *statsEntry;
   GtkWidget *chooser;
   char *fn;
   char *user;
@@ -290,6 +297,12 @@ on_startDaemon_clicked_daemon (GtkWidget * widget, gpointer data)
   else
     {
       GNUNET_GTK_add_log_entry (_("Launching gnunetd...\n"));
+      statsEntry =
+        glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
+                              "statusPixmap");
+      gtk_image_set_from_stock (GTK_IMAGE (statsEntry), GTK_STOCK_EXECUTE,
+                                GTK_ICON_SIZE_SMALL_TOOLBAR);
+
       chooser
         = glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
                                 "gnunetdconfigFileChooserButton");
@@ -350,6 +363,8 @@ on_startDaemon_clicked_daemon (GtkWidget * widget, gpointer data)
                                &cronCheckDaemon,
                                15 * GNUNET_CRON_SECONDS, NULL);
     }
+
+  on_gnunetdconfigfile_changed_daemon (NULL, NULL);
 }
 
 /**
@@ -359,8 +374,12 @@ void
 on_stopDaemon_clicked_daemon (GtkWidget * widget, gpointer data)
 {
   GtkWidget *killEntry = NULL;
+  GtkWidget *statsEntry;
   struct GNUNET_ClientServerConnection *sock;
+  int i;
 
+  GNUNET_cron_del_job (cron, &cronCheckDaemon, 15 * GNUNET_CRON_SECONDS,
+                       NULL);
   killEntry =
     glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (), "stopDaemon");
   gtk_widget_set_sensitive (killEntry, FALSE);
@@ -383,12 +402,25 @@ on_stopDaemon_clicked_daemon (GtkWidget * widget, gpointer data)
         }
       else
         {
+          statsEntry =
+            glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
+                                  "statusPixmap");
+          gtk_image_set_from_stock (GTK_IMAGE (statsEntry), GTK_STOCK_EXECUTE,
+                                    GTK_ICON_SIZE_SMALL_TOOLBAR);
           GNUNET_GTK_add_log_entry (_("Terminating gnunetd...\n"));
         }
       GNUNET_client_connection_destroy (sock);
     }
-  GNUNET_cron_advance_job (GNUNET_GTK_get_cron_manager (),
-                           &cronCheckDaemon, 15 * GNUNET_CRON_SECONDS, NULL);
+  for (i = 0; i < 10; i++)
+    GNUNET_cron_add_job (cron,
+                         &cronCheckDaemon,
+                         (i + 1) * 500 * GNUNET_CRON_MILLISECONDS, 0, NULL);
+}
+
+struct GNUNET_GC_Configuration *
+daemon_get_cfg_handle()
+{
+  return cfg;
 }
 
 void
@@ -435,39 +467,18 @@ init_daemon (struct GNUNET_GE_Context *e, struct GNUNET_GC_Configuration *c)
                                               "CONFIGFILE",
                                               GNUNET_DEFAULT_DAEMON_CONFIG_FILE,
                                               &daemon_config);
-  if (GNUNET_YES == GNUNET_disk_file_test (NULL, daemon_config))
-    {
-      gtk_file_chooser_set_filename (GTK_FILE_CHOOSER
-                                     (glade_xml_get_widget
-                                      (GNUNET_GTK_get_main_glade_XML (),
-                                       "gnunetdconfigFileChooserButton")),
-                                     daemon_config);
-    }
-  else
+  gtk_entry_set_text (GTK_ENTRY
+		      (glade_xml_get_widget
+		       (GNUNET_GTK_get_main_glade_XML (),
+			"configfilenameEntry")),
+		      daemon_config); 
+  if (GNUNET_YES != GNUNET_disk_file_test (NULL, daemon_config))
     {
       GNUNET_GTK_add_log_entry (_
                                 ("Configuration file for GNUnet daemon `%s' does not exist! Run `gnunet-setup -d'.\n"),
                                 daemon_config);
     }
-
-#ifndef WITH_LIBGKSU2
-  GtkWidget *startDaemonConfWizard;
-  GtkWidget *startDaemonConfTool;
-
-  startDaemonConfWizard
-    = glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                            "startDaemonConfWizard");
-  startDaemonConfTool
-    = glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                            "startDaemonConfTool");
-  if (0 != ACCESS (daemon_config, W_OK))
-    {
-      gtk_widget_set_sensitive (startDaemonConfWizard, FALSE);
-      gtk_widget_set_sensitive (startDaemonConfTool, FALSE);
-    }
-#endif
   GNUNET_free (daemon_config);
-
   cron = GNUNET_GTK_get_cron_manager ();
   GNUNET_cron_add_job (cron, &cronCheckDaemon, 2 * GNUNET_CRON_SECONDS,
                        15 * GNUNET_CRON_SECONDS, NULL);
@@ -495,77 +506,4 @@ done_daemon ()
 
 }
 
-/**
-* Launch 'gnunet-setup -d wizard-gtk' with needed rights
-*/
-void
-on_startDaemonConfWizard_clicked_daemon (GtkWidget * widget, gpointer data)
-{
-  GtkWidget *filechooserbutton;
-  char *conffile;
-
-  filechooserbutton
-    = glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                            "gnunetdconfigFileChooserButton");
-  conffile =
-    gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooserbutton));
-  GNUNET_GTK_run_gnunet_setup (conffile, TRUE);
-  GNUNET_free (conffile);
-}
-
-/**
-* Launch 'gnunet-setup -d gconfig' with needed rights
-*/
-void
-on_startDaemonConfTool_clicked_daemon (GtkWidget * widget, gpointer data)
-{
-  GtkWidget *filechooserbutton;
-  char *conffile;
-
-  filechooserbutton
-    = glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                            "gnunetdconfigFileChooserButton");
-  conffile =
-    gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooserbutton));
-  GNUNET_GTK_run_gnunet_setup (conffile, FALSE);
-  GNUNET_free (conffile);
-}
-
-/**
-* Update sensitivity of daemon buttons
-*/
-void
-on_gnunetdconfigfile_set_daemon (GtkWidget * filechooserbutton, gpointer data)
-{
-#ifndef WITH_LIBGKSU2
-  GtkWidget *startDaemonConfWizard;
-  GtkWidget *startDaemonConfTool;
-  char *conffile;
-  int ret;
-
-  startDaemonConfWizard
-    = glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                            "startDaemonConfWizard");
-  startDaemonConfTool
-    = glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                            "startDaemonConfTool");
-  conffile =
-    gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooserbutton));
-  if (0 == ACCESS (conffile, W_OK))
-    {
-      gtk_widget_set_sensitive (startDaemonConfWizard, TRUE);
-      gtk_widget_set_sensitive (startDaemonConfTool, TRUE);
-    }
-  else
-    {
-      gtk_widget_set_sensitive (startDaemonConfWizard, FALSE);
-      gtk_widget_set_sensitive (startDaemonConfTool, FALSE);
-    }
-  ret = 0;
-  GNUNET_GTK_save_call (&doUpdateMenus, &ret);
-  GNUNET_free_non_null (conffile);
-#endif
-  return;
-}
-
 /* end of daemon.c */
