@@ -145,7 +145,7 @@ refreshDirectoryViewFromDisk (DownloadList * list)
     }
   GNUNET_free_non_null (fn);
   meta = NULL;
-  GNUNET_ECRS_directory_list_contents (ectx, data, size, &meta,
+  GNUNET_ECRS_directory_list_contents (ectx, data, size, NULL, &meta,
                                        &addFilesToDirectory, list);
   MUNMAP ((void *) data, size);
   CLOSE (fd);
@@ -351,7 +351,7 @@ fs_download_update (DownloadList * list,
     {
       meta = NULL;
       GNUNET_ECRS_directory_list_contents (ectx,
-                                           data, size, &meta,
+                                           data, size, NULL, &meta,
                                            &addFilesToDirectory, list);
       if (meta != NULL)
         GNUNET_meta_data_destroy (meta);
@@ -453,7 +453,7 @@ fs_download_stopped (DownloadList * list)
 			 DOWNLOAD_META_DATA, &meta,
 			 -1);
       if (meta != NULL)
-	GNUNET_meta_data_destroy(meta);		 
+	GNUNET_meta_data_destroy(meta);
       gtk_tree_store_remove (download_summary, &iter);
     }
   GNUNET_free (list->filename);
@@ -483,7 +483,7 @@ fs_download_stopped (DownloadList * list)
 	    {
 	      do
 		{
-		  gtk_tree_store_set (list->searchList->tree, 
+		  gtk_tree_store_set (list->searchList->tree,
 				      &citer, SEARCH_INTERNAL_PARENT, NULL, -1);
 		}
 	      while (gtk_tree_model_iter_next (model, &citer));
@@ -516,6 +516,7 @@ fs_download_stopped (DownloadList * list)
 
 /* **************** user download events ******************** */
 
+
 /**
  * Check if a download for the given filename is
  * already running.
@@ -544,7 +545,7 @@ check_pending (const char *filename, GtkTreeIter * parent)
           if (name != NULL)
             free (name);
           if (GNUNET_SYSERR == check_pending (filename, &iter))
-            return GNUNET_SYSERR;
+	    return GNUNET_SYSERR;
         }
       while (gtk_tree_model_iter_next (model, &iter));
     }
@@ -750,7 +751,7 @@ initiateDownload (GtkTreeModel * model,
                                       "downloadAnonymitySpinButton");
   sdc.recursive = getToggleButtonValue (sdc.searchContext->searchXML,
                                         "downloadRecursiveCheckButton");
-  if (GNUNET_OK == check_pending (idc_name, NULL))
+  if (GNUNET_OK == check_pending (sdc.idc_final_download_destination, NULL))
     {
       GNUNET_GTK_add_log_entry (_("Downloading `%s'\n"), idc_name);
       GNUNET_GTK_run_with_save_calls (&init_download_helper, &sdc);
@@ -769,7 +770,7 @@ initiateDownload (GtkTreeModel * model,
 
 /**
  * The download button in the search dialog was
- * clicked.  GNUNET_ND_DOWNLOAD all selected entries.
+ * clicked.  Download all selected entries.
  */
 void
 on_downloadButton_clicked_fs (GtkWidget * treeview,
@@ -789,7 +790,13 @@ gboolean
 on_searchResults_button_press_fs (GtkWidget * treeview,
                                   GdkEventButton * event, gpointer data)
 {
-  if (event->type == GDK_2BUTTON_PRESS)
+  if (event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (treeview)))
+    return FALSE;
+  if ( (event->type == GDK_2BUTTON_PRESS) &&
+       (TRUE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview),
+					       event->x, event->y,
+					       NULL, NULL,
+					       NULL, NULL)) )
     on_downloadButton_clicked_fs (treeview, NULL);
   return FALSE;
 }
@@ -832,13 +839,6 @@ on_statusDownloadURIEntry_editing_done_fs (GtkWidget * entry,
       GNUNET_ECRS_uri_destroy (sdc.idc_uri);
       return;
     }
-  else if (GNUNET_ECRS_uri_test_loc (sdc.idc_uri))
-    {
-      GNUNET_GTK_add_log_entry (_("Location URIs are not yet supported"));
-      GNUNET_free (urid);
-      GNUNET_ECRS_uri_destroy (sdc.idc_uri);
-      return;
-    }
   GNUNET_GC_get_configuration_value_filename (cfg,
                                               "FS",
                                               "INCOMINGDIR",
@@ -968,7 +968,7 @@ fsuiShowMetaDataCallback (GtkTreeModel * model,
   GNUNET_GE_ASSERT (ectx,
 		    model == GTK_TREE_MODEL (download_summary));
   gtk_tree_model_get (model,
-		      iter, 
+		      iter,
 		      DOWNLOAD_META_DATA, &meta,
 		      DOWNLOAD_SHORTNAME, &name,
 		      -1);
