@@ -53,17 +53,6 @@ GtkTreeStore *download_summary;
 
 GtkTreeStore *upload_summary;
 
-/**
- * Last right-click event coordinates in summary.
- */
-static unsigned int last_x;
-
-/**
- * Last right-click event coordinates in summary.
- */
-static unsigned int last_y;
-
-
 void
 on_updateIntervalComboEntry_changed_fs (GtkWidget * button,
                                         GtkWidget * entryBox)
@@ -93,7 +82,8 @@ void
 on_anonymity_spin_changed_fs (GtkWidget * w, gpointer dummy)
 {
   gint val;
-  GdkColor color;
+  GdkColor bcolor;
+  GdkColor fcolor;
   GtkSpinButton *spin;
 
   spin = GTK_SPIN_BUTTON (w);
@@ -106,15 +96,23 @@ on_anonymity_spin_changed_fs (GtkWidget * w, gpointer dummy)
   if (val == 0)
     {
       if ((TRUE == gdk_color_parse ("red",
-                                    &color)) &&
+                                    &bcolor)) &&
           (TRUE == gdk_colormap_alloc_color (gdk_colormap_get_system (),
-                                             &color, FALSE, TRUE)))
-        gtk_widget_modify_base (w, GTK_STATE_NORMAL, &color);
+                                             &bcolor, FALSE, TRUE)) &&
+	  (TRUE == gdk_color_parse ("black",
+                                    &fcolor)) &&
+          (TRUE == gdk_colormap_alloc_color (gdk_colormap_get_system (),
+                                             &fcolor, FALSE, TRUE)))
+	{
+	  gtk_widget_modify_base (w, GTK_STATE_NORMAL, &bcolor);
+	  gtk_widget_modify_text (w, GTK_STATE_NORMAL, &fcolor);
+	}
     }
   else
-    gtk_widget_modify_base (w, GTK_STATE_NORMAL, NULL);
-
-
+    {
+      gtk_widget_modify_base (w, GTK_STATE_NORMAL, NULL);
+      gtk_widget_modify_text (w, GTK_STATE_NORMAL, NULL);
+    }
 }
 
 static void *
@@ -329,44 +327,6 @@ on_download_summary_selection_changed (gpointer signal, gpointer cls)
                             > 0);
 }
 
-int
-on_upload_copy_uri_activate_fs (void *dummy1, GtkWidget * dummy2)
-{
-  GtkWidget *uploadsList =
-    glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
-                          "activeUploadsList");
-  GtkTreePath *path;
-  GtkTreeIter iter;
-  struct GNUNET_ECRS_URI *uri;
-  char *str;
-  GtkClipboard *clip;
-
-  path = NULL;
-  if (FALSE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (uploadsList),
-                                              last_x,
-                                              last_y,
-                                              &path, NULL, NULL, NULL))
-    {
-      GNUNET_GE_BREAK (NULL, 0);
-      return FALSE;
-    }
-  if (FALSE == gtk_tree_model_get_iter (GTK_TREE_MODEL (upload_summary),
-                                        &iter, path))
-    {
-      GNUNET_GE_BREAK (NULL, 0);
-      gtk_tree_path_free (path);
-      return FALSE;
-    }
-  gtk_tree_path_free (path);
-  uri = NULL;
-  gtk_tree_model_get (GTK_TREE_MODEL (upload_summary),
-                      &iter, UPLOAD_URISTRING, &str, -1);
-  clip = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-  gtk_clipboard_set_text (clip, str, strlen (str));
-  GNUNET_free (str);
-  return FALSE;
-}
-
 /**
  * Setup the summary views (in particular the models
  * and the renderers).
@@ -383,6 +343,7 @@ fs_summary_start ()
   GtkTreeViewColumn *column;
   int col;
   GladeXML *contextMenuXML;
+  GtkTreeIter iter;
 
   /* keyword list setup */
   searchCB
@@ -405,6 +366,13 @@ fs_summary_start ()
                               G_TYPE_STRING,    /* GNUNET_EncName of namespace */
                               G_TYPE_POINTER,   /* ECRS MetaData */
                               G_TYPE_INT);      /* Meta-data about namespace */
+  gtk_list_store_append (model, &iter);
+  gtk_list_store_set (model,
+		      &iter,
+		      NS_SEARCH_DESCRIPTION, _("globally"),
+		      NS_SEARCH_NAME, _("globally"),
+		      NS_SEARCH_METADATA, NULL,
+		      NS_SEARCH_RATING, 0, -1);
   gtk_combo_box_set_model (GTK_COMBO_BOX (searchCB), GTK_TREE_MODEL (model));
   gtk_combo_box_entry_set_text_column (searchCB, NS_SEARCH_DESCRIPTION);
 
@@ -418,6 +386,7 @@ fs_summary_start ()
                                          G_TYPE_STRING, /* human readable size */
                                          G_TYPE_INT,    /* progress */
                                          G_TYPE_STRING, /* uri as string */
+					 G_TYPE_POINTER, /* meta data */
                                          G_TYPE_POINTER);       /* internal download list ptr */
   gtk_tree_view_set_model (downloadList, GTK_TREE_MODEL (download_summary));
   gtk_tree_selection_set_mode (gtk_tree_view_get_selection (downloadList),
@@ -582,7 +551,7 @@ init_cron_job (void *arg)
 {
   GtkWidget *tab = arg;
 
-  ctx = GNUNET_FSUI_start (ectx, cfg, "gnunet-gtk", 8,  /* FIXME: allow user to configure download parallelism */
+  ctx = GNUNET_FSUI_start (ectx, cfg, "gnunet-gtk", 64, /* FIXME: allow user to configure download parallelism */
                            GNUNET_YES, &eventProcessor, NULL);
   GNUNET_GTK_save_call ((GNUNET_ThreadMainFunction) & gtk_widget_show, tab);
 }
