@@ -38,6 +38,8 @@ publishMetaData (EXTRACTOR_KeywordType type, const char *data, void *cls)
   const char *stype;
   GtkTreeIter iter;
 
+  if (EXTRACTOR_isBinaryType (type))
+    return GNUNET_OK;
   stype = EXTRACTOR_getKeywordTypeAsString (type);
   if (stype == NULL)            /* wrong LE version!? */
     stype = _("unknown");
@@ -102,8 +104,6 @@ createMetaDataListTreeView (GladeXML * xml,
     GNUNET_meta_data_get_contents (init, &publishMetaData, metamodel);
   if ((previewName == NULL) || (init == NULL))
     return;
-  preview = glade_xml_get_widget (xml, previewName);
-
   thumb = NULL;
   ts = GNUNET_meta_data_get_thumbnail (init, &thumb);
   preview = glade_xml_get_widget (xml, previewName);
@@ -186,6 +186,9 @@ createMetaTypeComboBox (GladeXML * xml, const char *name)
                            GTK_TREE_MODEL (keywordTypeModel));
   for (type = 0; type < EXTRACTOR_getHighestKeywordTypeNumber (); type++)
     {
+      if ((type == EXTRACTOR_SPLIT) ||
+          (type == EXTRACTOR_LOWERCASE) || (EXTRACTOR_isBinaryType (type)))
+        continue;               /* these are not legal... */
       stype = EXTRACTOR_getKeywordTypeAsString (type);
       gtk_list_store_append (keywordTypeModel, &iter);
       gtk_list_store_set (keywordTypeModel,
@@ -524,4 +527,24 @@ getEntryLineValue (GladeXML * xml, const char *widgetName)
   return gtk_entry_get_text (entry);
 }
 
+
+void 
+open_meta_data_display_dialog(const struct GNUNET_MetaData * meta,
+			      const char * title)
+{
+  GladeXML *xml;
+  GtkWidget *dialog;
+
+  xml = glade_xml_new (GNUNET_GTK_get_glade_filename (),
+                       "metaDisplayDialog", PACKAGE_NAME);
+  GNUNET_GTK_connect_glade_with_plugins (xml);
+  dialog = glade_xml_get_widget (xml, "metaDisplayDialog");
+  gtk_window_set_title (GTK_WINDOW (dialog), title);
+  createMetaDataListTreeView (xml, "metaDisplayDialogTreeView", NULL, meta);
+  gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (dialog);
+  UNREF (xml);
+}
+
+
 /* end of meta.c */
