@@ -223,10 +223,13 @@ makeNamespaceFrame (NamespaceList * entry)
                                                  NULL);
   column = gtk_tree_view_get_column (GTK_TREE_VIEW (resultList), col - 1);
   gtk_tree_view_column_set_reorderable (column, TRUE);
+  gtk_tree_view_column_set_sort_column_id (column, IN_NAMESPACE_LAST_STRING);
+  gtk_tree_view_column_set_clickable (column, TRUE);
   gtk_tree_view_column_set_resizable (column, TRUE);
   gtk_tree_view_column_set_resizable (gtk_tree_view_get_column
                                       (GTK_TREE_VIEW (resultList), col - 1),
                                       TRUE);
+
   renderer = gtk_cell_renderer_text_new ();
   col =
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (resultList),
@@ -235,7 +238,9 @@ makeNamespaceFrame (NamespaceList * entry)
                                                  IN_NAMESPACE_NEXT_STRING,
                                                  NULL);
   column = gtk_tree_view_get_column (GTK_TREE_VIEW (resultList), col - 1);
+  gtk_tree_view_column_set_clickable (column, TRUE);
   gtk_tree_view_column_set_reorderable (column, TRUE);
+  gtk_tree_view_column_set_sort_column_id (column, IN_NAMESPACE_NEXT_STRING);
   gtk_tree_view_column_set_resizable (column, TRUE);
   gtk_tree_view_column_set_resizable (gtk_tree_view_get_column
                                       (GTK_TREE_VIEW (resultList), col - 1),
