@@ -76,10 +76,21 @@ updateResultsCount (SearchList * searchContext)
                      searchContext->searchString,
                      strlen (searchContext->searchString) > 20 ? "..." : "",
                      searchContext->resultsReceived);
+  if (new_title == NULL)
+    new_title =
+      g_strdup_printf (_("invalid characters (%u)"),
+		       searchContext->resultsReceived);
   label = GTK_LABEL (glade_xml_get_widget (searchContext->labelXML,
                                            "searchTabLabel"));
-  gtk_label_set (label, new_title);
-  GNUNET_free (new_title);
+  if (new_title != NULL) 
+    {
+      gtk_label_set (label, new_title);
+      GNUNET_free (new_title);
+    }
+  else
+    {
+      gtk_label_set (label, _("Internal error"));
+    }
 }
 
 static GdkPixbuf *
@@ -395,8 +406,6 @@ fs_search_update (SearchList * searchContext,
 }
 
 
-
-
 static int
 on_search_display_metadata_activate (void *cls, GtkWidget * searchEntry)
 {
@@ -406,8 +415,6 @@ on_search_display_metadata_activate (void *cls, GtkWidget * searchEntry)
   struct GNUNET_ECRS_URI *uri;
   struct GNUNET_MetaData *meta;
   char *str;
-  GladeXML *xml;
-  GtkWidget *dialog;
 
   path = NULL;
   if (FALSE == gtk_tree_view_get_path_at_pos (list->treeview,
@@ -431,16 +438,8 @@ on_search_display_metadata_activate (void *cls, GtkWidget * searchEntry)
   gtk_tree_model_get (GTK_TREE_MODEL (list->tree),
                       &iter, SEARCH_URI, &uri, SEARCH_META, &meta, -1);
   str = GNUNET_ECRS_uri_to_string (uri);
-  xml = glade_xml_new (GNUNET_GTK_get_glade_filename (),
-                       "metaDisplayDialog", PACKAGE_NAME);
-  GNUNET_GTK_connect_glade_with_plugins (xml);
-  dialog = glade_xml_get_widget (xml, "metaDisplayDialog");
-  gtk_window_set_title (GTK_WINDOW (dialog), str);
-  createMetaDataListTreeView (xml, "metaDisplayDialogTreeView", NULL, meta);
-  gtk_dialog_run (GTK_DIALOG (dialog));
+  open_meta_data_display_dialog(meta, str);
   GNUNET_free_non_null (str);
-  gtk_widget_destroy (dialog);
-  UNREF (xml);
   return FALSE;
 }
 
@@ -490,6 +489,7 @@ selectFile ()
   GladeXML *uploadXML;
   GtkFileChooser *dialog;
   char *ret;
+  gint gret;
 
   uploadXML
     = glade_xml_new (GNUNET_GTK_get_glade_filename (),
@@ -497,11 +497,12 @@ selectFile ()
   GNUNET_GTK_connect_glade_with_plugins (uploadXML);
   dialog = GTK_FILE_CHOOSER (glade_xml_get_widget (uploadXML,
                                                    "directorySaveDialog"));
-  if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_CANCEL)
+  gret = gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (GTK_WIDGET (dialog));
+  if (gret != GTK_RESPONSE_CANCEL)
     ret = gtk_file_chooser_get_filename (dialog);
   else
     ret = NULL;
-  gtk_widget_destroy (GTK_WIDGET (dialog));
   UNREF (uploadXML);
   return ret;
 }
@@ -1118,7 +1119,9 @@ on_fssearchbutton_clicked_fs (gpointer dummy2, GtkWidget * searchButton)
                           NS_SEARCH_DESCRIPTION, &descStr, NS_SEARCH_NAME,
                           &nsName, -1);
 
-      if ((descStr != NULL) && (0 == strcmp (descStr, "")))
+      if ((descStr != NULL) &&
+	  ( (0 == strcmp (descStr, "")) ||
+	    (0 == strcmp (descStr, _("globally")))))
         {
           nsName = NULL;
         }
@@ -1164,6 +1167,11 @@ on_fssearchbutton_clicked_fs (gpointer dummy2, GtkWidget * searchButton)
       if (nsName != NULL)
         free (nsName);
     }
+  else
+    {
+      /* FIXME: may still be namespace-search
+	 -- where user manually entered NS name*/
+    }
   if (fsss.uri == NULL)
     fsss.uri = GNUNET_ECRS_keyword_string_to_uri (ectx, searchString);
   if (fsss.uri == NULL)
