@@ -447,10 +447,13 @@ on_fsinsertuploadbutton_clicked_fs (gpointer dummy, GtkWidget * uploadButton)
   while ((filenamerest > filename) && (filenamerest[-1] != DIR_SEPARATOR))
     filenamerest--;
   GNUNET_meta_data_insert (meta, EXTRACTOR_FILENAME, filenamerest);
+  keywordURI = GNUNET_meta_data_to_uri (meta);
+  while (GNUNET_OK == GNUNET_meta_data_delete (meta, EXTRACTOR_SPLIT, NULL));
+  while (GNUNET_OK ==
+         GNUNET_meta_data_delete (meta, EXTRACTOR_LOWERCASE, NULL));
   createMetaDataListTreeView (metaXML,
                               "metaDataDialogMetaDataList",
                               "previewImage", meta);
-  keywordURI = GNUNET_meta_data_to_uri (meta);
   GNUNET_meta_data_destroy (meta);
   createKeywordListTreeView (metaXML,
                              "metaDataDialogKeywordList", keywordURI);
@@ -499,8 +502,10 @@ on_fsinsertuploadbutton_clicked_fs (gpointer dummy, GtkWidget * uploadButton)
       GNUNET_GTK_run_with_save_calls (&start_upload_helper, &fsuc);
       GNUNET_free (fsuc.filename);
       GNUNET_meta_data_destroy (fsuc.meta);
-      GNUNET_ECRS_uri_destroy (fsuc.gkeywordURI);
-      GNUNET_ECRS_uri_destroy (fsuc.keywordURI);
+      if (fsuc.gkeywordURI != NULL)
+	GNUNET_ECRS_uri_destroy (fsuc.gkeywordURI);
+      if (fsuc.keywordURI != NULL)
+	GNUNET_ECRS_uri_destroy (fsuc.keywordURI);
     }
   gtk_widget_destroy (dialog);
   UNREF (metaXML);
@@ -665,6 +670,33 @@ on_clearCompletedUploads_clicked_fs (void *unused, GtkWidget * clearButton)
                                  &clearCompletedUploadCallback, NULL);
 }
 
+static void
+do_copy_uri (GtkTreeModel * model,
+             GtkTreePath * path, GtkTreeIter * iter, gpointer unused)
+{
+  char *str;
+  GtkClipboard *clip;
+
+  gtk_tree_model_get (model, iter, UPLOAD_URISTRING, &str, -1);
+  clip = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
+  gtk_clipboard_set_text (clip, str, strlen (str));
+  GNUNET_free (str);
+}
+
+int
+on_upload_copy_uri_activate_fs (void *dummy1, GtkWidget * dummy2)
+{
+  GtkTreeSelection *selection;
+  GtkWidget *uploadList;
+
+  uploadList =
+    glade_xml_get_widget (GNUNET_GTK_get_main_glade_XML (),
+                          "activeUploadsList");
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (uploadList));
+  GNUNET_GTK_tree_selection_selected_foreach (selection, &do_copy_uri, NULL);
+  return FALSE;
+}
+
 static void
 fsuiCallUploadCallback (GtkTreeModel * model,
                         GtkTreePath * path,
